# Curso de Stable Diffusion con Hugging Face


## Programa

| 🗓 Fecha        | 📘 Unidad                             | 🧑‍💻 Laboratorio                                                              |
|----------------|--------------------------------------|-----------------------------------------------------------------------------|
| Abril 04, 2023 | Introducción a Stable Diffusion      | [lab1](https://github.com/mfidabel/fpuna_stable_diffusion/tree/master/lab1) |
| Abril 06, 2023 | Personalizando Stable Diffusion      | [lab2](https://github.com/mfidabel/fpuna_stable_diffusion/tree/master/lab2) |
| Abril 11, 2023 | Usos avanzados de Stable Diffusion   | [lab3](https://github.com/mfidabel/fpuna_stable_diffusion/tree/master/lab3) |
| Abril 13, 2023 | Web UI & Ganadores de la Competencia | [lab4](https://github.com/mfidabel/fpuna_stable_diffusion/tree/master/lab4) |

## Requisitos

- Manejo básico de Python 🐍
- Conexión a Internet

# Instrucciones

Los laboratorios estan hechos para ser completados a cualquier ritmo. Al final de cada cuaderno, habrá ejercicios para completar.

## Ejecutando los laboratorios

Para correr los laboratorios, abre el cuaderno en Colab. Navega hasta la pestaña de "Entorno de Ejecución" --> "Cambiar tipo de entorno de ejecución". En la ventanilla que se abre, debajo de "Acelerador por hardware", selecciona "GPU". Lee los cuadernos y completa las celdas que contienen #TODO por tu cuenta.

TODO:

